@@ -1,6 +1,7 @@
 from datetime import datetime
-from provider.oauth2.forms import ClientAuthForm
-from provider.oauth2.models import Client, AccessToken
+from .forms import ClientAuthForm
+from .models import AccessToken
+
 
 class BaseBackend(object):
     """
@@ -14,28 +15,31 @@ class BaseBackend(object):
         """
         pass
 
+
 class BasicClientBackend(object):
     """
-    Backend that tries to authenticate a client through HTTP authorization headers
-    as defined in :draft:`2.3.1`.
+    Backend that tries to authenticate a client through HTTP authorization
+    headers as defined in :draft:`2.3.1`.
     """
     def authenticate(self, request=None):
         auth = request.META.get('HTTP_AUTHORIZATION')
 
         if auth is None or auth == '':
             return None
-        
+
         try:
             basic, base64 = auth.split(' ')
             client_id, client_secret = base64.decode('base64').split(':')
-            
-            form = ClientAuthForm({'client_id': client_id, 'client_secret': client_secret})
-            
+
+            form = ClientAuthForm({
+                'client_id': client_id,
+                'client_secret': client_secret})
+
             if form.is_valid():
                 return form.cleaned_data.get('client')
             return None
 
-        except ValueError, e:
+        except ValueError:
             # Auth header was malformed, unpacking went wrong
             return None
 
@@ -48,24 +52,23 @@ class RequestParamsClientBackend(object):
     def authenticate(self, request=None):
         if request is None:
             return None
-        
+
         form = ClientAuthForm(request.REQUEST)
-        
+
         if form.is_valid():
             return form.cleaned_data.get('client')
-        
+
         return None
-        
-        
+
+
 class AccessTokenBackend(object):
-    """ 
+    """
     Authenticate a user via access token and client object.
     """
-    
+
     def authenticate(self, access_token=None, client=None):
         try:
             return AccessToken.objects.get(token=access_token,
                 expires__gt=datetime.now(), client=client)
         except AccessToken.DoesNotExist:
             return None
-
