@@ -1,8 +1,8 @@
-from datetime import datetime
-from django.conf import settings
-from provider.constants import EXPIRE_DELTA, EXPIRE_CODE_DELTA
 import hashlib
 import shortuuid
+from datetime import datetime
+from django.conf import settings
+from .constants import EXPIRE_DELTA, EXPIRE_CODE_DELTA
 
 
 def short_token():
@@ -13,6 +13,7 @@ def short_token():
     hash.update(settings.SECRET_KEY)
     return hash.hexdigest()[::2]
 
+
 def long_token():
     """
     Generate a hash that can be used as an application secret
@@ -20,21 +21,22 @@ def long_token():
     hash = hashlib.sha1(shortuuid.uuid())
     hash.update(settings.SECRET_KEY)
     return hash.hexdigest()
-    
+
+
 def get_token_expiry():
     """
-    Return a datetime object indicating when an access token should expire. 
-    Can be customized by setting :attr:`settings.OAUTH_EXPIRE_DELTA` to a 
+    Return a datetime object indicating when an access token should expire.
+    Can be customized by setting :attr:`settings.OAUTH_EXPIRE_DELTA` to a
     :attr:`datetime.timedelta` object.
     """
     return datetime.now() + EXPIRE_DELTA
 
+
 def get_code_expiry():
     """
-    Return a datetime object indicating when an authorization code should 
+    Return a datetime object indicating when an authorization code should
     expire.
-    Can be customized by setting :attr:`settings.OAUTH_EXPIRE_CODE_DELTA` to a 
+    Can be customized by setting :attr:`settings.OAUTH_EXPIRE_CODE_DELTA` to a
     :attr:`datetime.timedelta` object.
     """
     return datetime.now() + EXPIRE_CODE_DELTA
-
